/*
 * Path functions.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <string.h>

#include "path.h"

/* Return the basename from a path. */

const char *path_basename(const char *path)
{
    char *s = strrchr(path, (int) '/');

    if (s == NULL)
        return path;
    else
        return s + 1;
}

/* Return the end of the first component in the given path. */

const char *path_component_end(const char *path)
{
    char *end = strchr(path, (int) '/');

    if (end == NULL)
        return path + strlen(path);
    else
        return end;
}

/* Return the start of the next component in a path given the end of the
   previous one. */

const char *path_component_next(const char *end)
{
    if (*end)
        return end + 1;
    else
        return end;
}

/* Return whether the path lacks a path separator. */

int path_is_leafname(const char *path)
{
    return strchr(path, (int) '/') == NULL;
}

/* Split a path into directory and basename components, returning a pointer to
   the basename component. */

char *path_split(char *path)
{
    char *s = strrchr(path, (int) '/');

    if (s != NULL)
    {
        *s = '\0';
        return s + 1;
    }
    else
        return path;
}
