/*
 * Notification-related functions.
 *
 * Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <notifier/notifier.h>

#include "notify.h"



/* Opaque notifier type for notifier_t. */

struct notifier
{
  ObjectNotifier *obj;
};

/* Return the notifiable details from a compatible object. */

notifiable_t *notify_notifiable(notifiable_base_t *notifiable)
{
  return &notifiable->notifiable;
}

/* Return the notification flags for an object. */

notify_flags_t notify_notifications(notifiable_base_t *notifiable)
{
  return notifiable->notifiable.notifications;
}

/* Return the notification values for an object. */

notify_values_t notify_notification_values(notifiable_base_t *notifiable)
{
  return notifiable->notifiable.values;
}

/* Close a notifier object. */

void notify_close(notifier_t *notifier)
{
  delete notifier->obj;
  delete notifier;
}

/* Obtain a local notifier object. */

notifier_t *notify_get_local()
{
  notifier_t *notifier = new notifier_t;

  notifier->obj = notifier_get_local_notifier();
  return notifier;
}

/* Obtain the task-wide notifier object. */

notifier_t *notify_get_task()
{
  notifier_t *notifier = new notifier_t;

  notifier->obj = notifier_get_task_notifier();
  return notifier;
}

/* Subscribe to notification events. */

long notify_subscribe(notifiable_t *notifiable, notify_flags_t flags, notifier_t *notifier)
{
  return notifier->obj->subscribe(notifiable, flags);
}

/* Unsubscribe from notification events. */

long notify_unsubscribe(notifiable_t *notifiable, notifier_t *notifier)
{
  return notifier->obj->unsubscribe(notifiable);
}

/* Wait for a notification event on a single object. */

long notify_wait(notifiable_t *notifiable, notifier_t *notifier)
{
  return notifier->obj->wait_object(notifiable);
}

/* Wait for notification events on multiple objects. */

long notify_wait_many(notifiable_t **notifiable, notifier_t *notifier)
{
  return notifier->obj->wait(notifiable);
}

// vim: tabstop=2 expandtab shiftwidth=2
